@@ -1,5 +1,8 @@
 #!/usr/bin/env python3
 """
+FOR CONNECTION TO FLASHCAM AND NOTIFATOR - SEE FLASHCAM README.org
+
+
 This code reads serial device. Different ways possible, initial setting
  - arduino (json)
  - ORTEC COUNTER (text)
@@ -37,7 +40,7 @@ OUTPUT
 #
 #
 from fire import Fire
-from version import __version__
+from seread.version import __version__
 
 from asyncio import get_event_loop
 from serial_asyncio import open_serial_connection
@@ -104,13 +107,13 @@ import mmap
 
 # -------------------------------------------------------------------------
 def mmcreate():
-    global MMAPFILE
+    global MMAPFILE, MMAPSIZE
     with open(MMAPFILE, "w") as f:
-        f.write("-"*100)
+        f.write("-"*MMAPSIZE)
 
 def mmwrite( imgname ):
     """
-    write text to filename
+    apply image to flashcam
     """
     global MMAPFILE
     if imgname is None:
@@ -127,6 +130,23 @@ def mmwrite( imgname ):
             mmap_obj.write( CMD.encode("utf8") )  # 2ms
             mmap_obj.flush()
 
+
+def mmtelegram( teletext ):
+    """
+    send command to flashcam - send_telegram
+    """
+    global MMAPFILE
+    if teletext is None:
+        teletext = "None"
+    if not os.path.exists(MMAPFILE):
+        mmcreate()
+    with open(MMAPFILE, mode="r+", encoding="utf8") as file_obj:
+        with mmap.mmap(file_obj.fileno(), length=0, access=mmap.ACCESS_WRITE, offset=0) as mmap_obj:
+
+            CMD = f'send_telegram "{teletext}"'
+            mmap_obj.write( CMD.encode("utf8") )  # 2ms
+            mmap_obj.flush()
+
 # -------------------------------------------------------------------------
 
 
@@ -230,6 +250,9 @@ def translate_net2json( res ):
 
 
     # D...  influxmevac vac102 09.04.2021 14:26:12 _ P1= 0.00E+0 _ P2= 0.00E+0 ... FL+++
+
+
+    #============== space separated inflbeam nfs count STATUS #ra #pos time===
     if res.find("influxmebeam ")==0:
         # print(res)
         t = datetime.datetime.now().strftime("%Y/%m/%d %H:%M:%S.%f")
@@ -248,14 +271,35 @@ def translate_net2json( res ):
         # print(r.split(" ") )
 
 
-        measu,counter,status,rabbit,position,time = r.strip().split(" ")
+        okbobo = False
+        try:
+            measu,counter,status,rabbit,position,time = r.strip().split(" ")
+            # nfs, ?,       BEAM_ON_,29, 4,
+            okbobo = True
+        except:
+            okbobo = False # Not beamon beamoff TYPE
 
-        if not(status in ["BEAM_ON_", "BEAM_OFF", "DET_RDY_","DET_NRDY"]):
+        if okbobo and not(status in ["BEAM_ON_", "BEAM_OFF", "DET_RDY_","DET_NRDY"]):
             print("X... bad unknown status:", status )
-            return
+            okbobo = False
 
-        # flashcam !!!
-        mmwrite( status )
+        # ---- what if it is START_RUN   STOP_RUN  type?: Test it:
+        if not okbobo:
+            # ---- STOP_RUN   START_RUN ... ???
+            if r.find("STOP_RUN")>0:
+                #r.split("STOP_RUN")[-1]
+                print("tele: run_stop")
+                mmtelegram("run_stop")
+            if r.find("START_RUN")>0:
+                r2 = r.split("START_RUN")[-1]
+                #r2.split("_")
+                print("tele: start_run")
+                mmtelegram("start_run_"+r2)
+            return False
+
+        # send to         flashcam !!!
+        print("i... changing image in flashcam, rec2influx")
+        mmwrite( status )   # show corresponding image
 
 
         value = 100
